@@ -22,8 +22,13 @@ classicthemerestorerjso.ctr = {
   tmp_tu_active:	false,
   // Exclude all preferences we don't want to sync, export or import.
   blacklist: [
-	"extensions.classicthemerestorer.pref_actindx",
-	"extensions.classicthemerestorer.pref_actindx2",
+	"extensions.classicthemerestorer.pw_actidx_c",
+	"extensions.classicthemerestorer.pw_actidx_t",
+	"extensions.classicthemerestorer.pw_actidx_tc",
+	"extensions.classicthemerestorer.pw_actidx_g",
+	"extensions.classicthemerestorer.pw_actidx_tb",
+	"extensions.classicthemerestorer.pw_actidx_lb",
+	"extensions.classicthemerestorer.pw_actidx_sb",
 	"extensions.classicthemerestorer.ctrreset"
 	],
 
@@ -49,8 +54,13 @@ classicthemerestorerjso.ctr = {
 	} catch(e){}
 	
 	// restore last selected categories/tabs
-	document.getElementById("CtrRadioGroup").selectedIndex = this.prefs.getIntPref('pref_actindx');
-	document.getElementById("ctraddon_tabcolor_tabs").selectedIndex = this.prefs.getIntPref('pref_actindx2');
+	document.getElementById("CtrRadioGroup").selectedIndex = this.prefs.getIntPref('pw_actidx_c');
+	document.getElementById("ctraddon_pw_tabs_tabs").selectedIndex = this.prefs.getIntPref('pw_actidx_t');
+	document.getElementById("ctraddon_tabcolor_tabs").selectedIndex = this.prefs.getIntPref('pw_actidx_tc');
+	document.getElementById("ctraddon_pw_generalui_tabs").selectedIndex = this.prefs.getIntPref('pw_actidx_g');
+	document.getElementById("ctraddon_pw_toolbars_tabs").selectedIndex = this.prefs.getIntPref('pw_actidx_tb');
+	document.getElementById("ctraddon_pw_locationbar_tabs").selectedIndex = this.prefs.getIntPref('pw_actidx_lb');
+	document.getElementById("ctraddon_pw_searchbar_tabs").selectedIndex = this.prefs.getIntPref('pw_actidx_sb');
 	
 	// disable and hide items not usable on third party themes
 	if (!this.fxdefaulttheme) {
@@ -416,7 +426,8 @@ classicthemerestorerjso.ctr = {
 	}
 
 	if (this.appversion < 51) {
-	  document.getElementById('ctraddon_pw_oneoffsearchgb').style.visibility = 'collapse';
+	  document.getElementById('ctraddon_pw_oneoffsearch').style.visibility = 'collapse';
+	  document.getElementById('ctraddon_pw_oneoffsearch_desc').style.visibility = 'collapse';
 	  document.getElementById('ctraddon_pw_hideurlzoom').style.visibility = 'collapse';
 	  document.getElementById('ctraddon_pw_dl_pm_drop').style.visibility = 'collapse';
 	  document.getElementById('ctraddon_pw_dl_pm_dropdes').style.visibility = 'collapse';
@@ -581,12 +592,13 @@ classicthemerestorerjso.ctr = {
 	this.ctrpwHidetbwotExtra(this.prefs.getBoolPref("hidetbwot"));
 	this.altTabsToolbarBgExtra(this.prefs.getBoolPref("alttabstb"));
 	this.ctrpwModeextra(this.prefs.getCharPref("nav_txt_ico"));
-	this.currentTabAppearance(this.prefs.getCharPref("tabs"));
 	this.currentAboutPrefs(this.prefs.getCharPref("altoptions"));
 	this.ctrpwTranspTbW10(this.prefs.getBoolPref("transpttbw10"));
 	this.ctrpwNavBarPadding(this.prefs.getBoolPref("navbarpad"));
-	this.ctrpwLocationSearchbarSize(this.prefs.getBoolPref("lbsbsize"));
-	this.ctrpwLocationSearchbarRadius(this.prefs.getBoolPref("lbsbradius"));
+	this.ctrpwLocationbarSize(this.prefs.getBoolPref("lb_width"));
+	this.ctrpwSearchbarSize(this.prefs.getBoolPref("sb_width"));
+	this.ctrpwLocationbarRadius(this.prefs.getBoolPref("lb_roundness"));
+	this.ctrpwSearchbarRadius(this.prefs.getBoolPref("sb_roundness"));
 	if (this.fxdefaulttheme) this.ctrpwCompactAddonList(this.prefs.getBoolPref("am_compact"));
 	this.ctrpwUnsortBM(this.prefs.getBoolPref("bmbunsortbm"));
 	this.ctrpwHideUrlStopRel(this.prefs.getBoolPref("hideurelstop"));
@@ -645,8 +657,13 @@ classicthemerestorerjso.ctr = {
 	}
 	
 	// save last selected categories/tabs
-	this.prefs.setIntPref('pref_actindx',document.getElementById("CtrRadioGroup").selectedIndex);
-	this.prefs.setIntPref('pref_actindx2',document.getElementById("ctraddon_tabcolor_tabs").selectedIndex);
+	this.prefs.setIntPref('pw_actidx_c',document.getElementById("CtrRadioGroup").selectedIndex);
+	this.prefs.setIntPref('pw_actidx_t',document.getElementById("ctraddon_pw_tabs_tabs").selectedIndex);
+	this.prefs.setIntPref('pw_actidx_tc',document.getElementById("ctraddon_tabcolor_tabs").selectedIndex);
+	this.prefs.setIntPref('pw_actidx_g',document.getElementById("ctraddon_pw_generalui_tabs").selectedIndex);
+	this.prefs.setIntPref('pw_actidx_tb',document.getElementById("ctraddon_pw_toolbars_tabs").selectedIndex);
+	this.prefs.setIntPref('pw_actidx_lb',document.getElementById("ctraddon_pw_locationbar_tabs").selectedIndex);
+	this.prefs.setIntPref('pw_actidx_sb',document.getElementById("ctraddon_pw_searchbar_tabs").selectedIndex);
 
 	return true;
   },
@@ -671,7 +688,21 @@ classicthemerestorerjso.ctr = {
 	  this.prefs.setBoolPref('aerocolors',false);
  
 	this.hideThemeInfoForTabs();
-	this.unsetTabColorsAndMore();
+
+	this.prefs.setBoolPref('tabcolor_def',false);
+	this.prefs.setBoolPref('tabcolor_act',false);
+	this.prefs.setBoolPref('tabcolor_pen',false);
+	this.prefs.setBoolPref('tabcolor_unr',false);
+	this.prefs.setBoolPref('tabcolor_hov',false);
+	this.prefs.setBoolPref('ntabcolor_def',false);
+	this.prefs.setBoolPref('ntabcolor_hov',false);
+	
+	if(this.prefs.getBoolPref('closeonleft')) {
+	  this.prefs.setBoolPref('closeonleft',false);
+	  setTimeout(function(){
+		Services.prefs.getBranch("extensions.classicthemerestorer.").setBoolPref('closeonleft',true);
+	  },20);
+	}
 
   },
  
@@ -691,23 +722,6 @@ classicthemerestorerjso.ctr = {
 	},100);
   },
 
-  unsetTabColorsAndMore: function() {
-	this.prefs.setBoolPref('tabcolor_def',false);
-	this.prefs.setBoolPref('tabcolor_act',false);
-	this.prefs.setBoolPref('tabcolor_pen',false);
-	this.prefs.setBoolPref('tabcolor_unr',false);
-	this.prefs.setBoolPref('tabcolor_hov',false);
-	this.prefs.setBoolPref('ntabcolor_def',false);
-	this.prefs.setBoolPref('ntabcolor_hov',false);
-	
-	if(this.prefs.getBoolPref('closeonleft')) {
-	  this.prefs.setBoolPref('closeonleft',false);
-	  setTimeout(function(){
-		Services.prefs.getBranch("extensions.classicthemerestorer.").setBoolPref('closeonleft',true);
-	  },20);
-	}
-  },
-  
   ctrpwFaviconextra: function(which) {
 	if(which==true) which=false; else which=true;
 	document.getElementById('ctraddon_padlock_extra').disabled = which;
@@ -797,28 +811,42 @@ classicthemerestorerjso.ctr = {
 	document.getElementById('ctraddon_pw_navbarmar_lr').style.visibility = itemvis;
   },
   
-  ctrpwLocationSearchbarSize: function(which) {
+  ctrpwLocationbarSize: function(which) {
 	
     if(which==true) which=false;
 	else which=true;
 	
-    document.getElementById('ctraddon_pw_lbsbsize_lb').disabled = which;
-    document.getElementById('ctraddon_pw_lbsbsize_sb').disabled = which;
+    document.getElementById('ctraddon_pw_lb_width').disabled = which;
 	document.getElementById('ctraddon_lbsize_minw').disabled = which;
 	document.getElementById('ctraddon_lbsize_maxw').disabled = which;
+  },
+  
+  ctrpwSearchbarSize: function(which) {
+	
+    if(which==true) which=false;
+	else which=true;
+	
+    document.getElementById('ctraddon_pw_sb_width').disabled = which;
 	document.getElementById('ctraddon_sbsize_minw').disabled = which;
 	document.getElementById('ctraddon_sbsize_maxw').disabled = which;
   },
   
-  ctrpwLocationSearchbarRadius: function(which) {
+  ctrpwLocationbarRadius: function(which) {
 	
     if(which==true) which=false;
 	else which=true;
 	
     document.getElementById('ctraddon_pw_lbsbradius_lb').disabled = which;
-    document.getElementById('ctraddon_pw_lbsbradius_sb').disabled = which;
 	document.getElementById('ctraddon_lbradius_left').disabled = which;
 	document.getElementById('ctraddon_lbradius_right').disabled = which;
+  },
+  
+  ctrpwSearchbarRadius: function(which) {
+	
+    if(which==true) which=false;
+	else which=true;
+	
+    document.getElementById('ctraddon_pw_lbsbradius_sb').disabled = which;
 	document.getElementById('ctraddon_sbradius_left').disabled = which;
 	document.getElementById('ctraddon_sbradius_right').disabled = which;
   },
@@ -1121,18 +1149,7 @@ classicthemerestorerjso.ctr = {
 	}
   
   },
-  
-  currentTabAppearance: function(which) {
-	
-	if(which=="tabs_squaredc2" || which=="tabs_squared2c2") {
-	  document.getElementById('ctraddon_pw_square_edges').disabled = false;
-	  document.getElementById('ctraddon_pw_square_edges').style.visibility = 'visible';
-	} else {
-	  document.getElementById('ctraddon_pw_square_edges').disabled = true;
-	  document.getElementById('ctraddon_pw_square_edges').style.visibility = 'collapse';
-	}
-  },
-  
+ 
   currentAboutPrefs: function(which) {
 	
 	if(which=="options_win" || which=="options_win_alt") {
